summaryrefslogtreecommitdiffstats
path: root/ksvg/impl/SVGLangSpaceImpl.cc
diff options
context:
space:
mode:
Diffstat (limited to 'ksvg/impl/SVGLangSpaceImpl.cc')
-rw-r--r--ksvg/impl/SVGLangSpaceImpl.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/ksvg/impl/SVGLangSpaceImpl.cc b/ksvg/impl/SVGLangSpaceImpl.cc
index 92919698..5a55ef15 100644
--- a/ksvg/impl/SVGLangSpaceImpl.cc
+++ b/ksvg/impl/SVGLangSpaceImpl.cc
@@ -67,19 +67,19 @@ TQString SVGLangSpaceImpl::handleText(const TQString &data) const
{
// Spec: What to do here?
// It will convert all newline and tab characters into space characters
- result.replace("\n\r", TQString(" "));
- result.replace("\r\n", TQString(" "));
- result.replace('\t', ' ');
+ result.tqreplace("\n\r", TQString(" "));
+ result.tqreplace("\r\n", TQString(" "));
+ result.tqreplace('\t', ' ');
}
else if(xmlspace() == "default")
{
// Spec: What to do here?
// First, it will remove all newline characters (replace)
// Then it will convert all tab characters into space characters (simplifyWhiteSpace)
// Then, it will strip off all leading and trailing space characters (stripWhiteSpace)
// Then, all contiguous space characters will be consolidated. (simplifyWhiteSpace)
- result.replace('\n', TQString::null);
- result.replace('\r', TQString::null);
+ result.tqreplace('\n', TQString());
+ result.tqreplace('\r', TQString());
result = result.stripWhiteSpace().simplifyWhiteSpace();
}
@@ -67,19 +67,19 @@ TQString SVGLangSpaceImpl::handleText(const TQString &data) const
{
// Spec: What to do here?
- // First, it will remove all newline characters (replace)
+ // First, it will remove all newline characters (tqreplace)
// Then it will convert all tab characters into space characters (simplifyWhiteSpace)
// Then, it will strip off all leading and trailing space characters (stripWhiteSpace)